==> apache-camel-4.10.7-src.zip: apache-camel-4.10.7/catalog/camel-catalog-maven/src/test/java/org/apache/camel/catalog/maven/MavenArtifactProviderManualTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.catalog.maven;

import java.io.File;
import java.net.MalformedURLException;
import java.util.Set;

import org.apache.camel.catalog.CamelCatalog;
import org.apache.camel.catalog.DefaultCamelCatalog;
import org.junit.jupiter.api.Disabled;
import org.junit.jupiter.api.Test;

import static org.junit.jupiter.api.Assertions.assertEquals;
import static org.junit.jupiter.api.Assertions.assertTrue;

@Disabled("Cannot run on CI servers so run manually")
@Deprecated
public class MavenArtifactProviderManualTest {

    @Test
    public void testAddComponent() throws MalformedURLException {
        CamelCatalog camelCatalog = new DefaultCamelCatalog();
        MavenArtifactProvider provider = new DefaultMavenArtifactProvider();
        provider.setCacheDirectory("target/cache");

        int before = camelCatalog.findComponentNames().size();

        // use ~/.m2/repository as one of the remote repos - I needed it to test dummy-component SNAPSHOT
        // fixed only locally (and also when Apache Snapshots repo was down)
        provider.addMavenRepository("local",
                new File(System.getProperty("user.home"), ".m2/repository").toURI().toURL().toString());
        Set<String> names = provider.addArtifactToCatalog(camelCatalog, "org.apache.camel", "dummy-component",
                camelCatalog.getCatalogVersion());
        assertTrue(names.contains("dummy"));

        int after = camelCatalog.findComponentNames().size();

        assertEquals(1, after - before, "Should find 1 new component");
    }

}

==> apache-camel-4.18.0-src.zip: apache-camel-4.18.0/catalog/camel-catalog-maven/src/test/java/org/apache/camel/catalog/maven/MavenArtifactProviderManualTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.catalog.maven;

import java.io.File;
import java.net.MalformedURLException;
import java.util.Set;

import org.apache.camel.catalog.CamelCatalog;
import org.apache.camel.catalog.DefaultCamelCatalog;
import org.apache.camel.util.HomeHelper;
import org.junit.jupiter.api.Disabled;
import org.junit.jupiter.api.Test;

import static org.junit.jupiter.api.Assertions.assertEquals;
import static org.junit.jupiter.api.Assertions.assertTrue;

@Disabled("Cannot run on CI servers so run manually")
@Deprecated
public class MavenArtifactProviderManualTest {

    @Test
    public void testAddComponent() throws MalformedURLException {
        CamelCatalog camelCatalog = new DefaultCamelCatalog();
        MavenArtifactProvider provider = new DefaultMavenArtifactProvider();
        provider.setCacheDirectory("target/cache");

        int before = camelCatalog.findComponentNames().size();

        // use ~/.m2/repository as one of the remote repos - I needed it to test dummy-component SNAPSHOT
        // fixed only locally (and also when Apache Snapshots repo was down)
        provider.addMavenRepository("local",
                new File(HomeHelper.resolveHomeDir(), ".m2/repository").toURI().toURL().toString());
        Set<String> names = provider.addArtifactToCatalog(camelCatalog, "org.apache.camel", "dummy-component",
                camelCatalog.getCatalogVersion());
        assertTrue(names.contains("dummy"));

        int after = camelCatalog.findComponentNames().size();

        assertEquals(1, after - before, "Should find 1 new component");
    }

}
